binpath

package
v1.1.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Oct 7, 2026 License: GPL-3.0 Imports: 3 Imported by: 0

Documentation

Overview

Package binpath resolves the path of the running sync82 binary.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Resolve

func Resolve() (string, error)

Resolve returns the absolute path of the running executable with symlinks resolved, so it names the real file. When the symlinks cannot be resolved, the unresolved path is returned. It returns an error only when the operating system cannot report the executable path.

Types

This section is empty.

Jump to